@@ -1,8 +1,8 @@
 <?php
-/*
- * $Horde: kronolith/delevent.php,v 1.25.2.1 2002/04/23 17:59:48 chuck Exp $
+/**
+ * $Horde: kronolith/delevent.php,v 1.25.2.6 2005/01/03 11:25:57 jan Exp $
  *
- * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -12,7 +12,16 @@ define('KRONOLITH_BASE', dirname(__FILE__));
 require_once KRONOLITH_BASE . '/lib/base.php';
 
 $event = $calendar->getEventObject(Horde::getFormData('eventID'));
-if ($event->hasRecurType(KRONOLITH_RECUR_NONE) &&
+if (!$event) {
+    if (($url = Horde::getFormData('url')) === null) {
+        $url = $prefs->getValue('defaultview') . '.php';
+        if ($url == '.php') {
+            $url = 'month.php';
+        }
+        $url = Horde::applicationUrl($url, true);
+    }
+    header('Location: ' . $url);
+} elseif ($event->hasRecurType(KRONOLITH_RECUR_NONE) &&
     !$prefs->getValue('confirm_delete')) {
     header('Location: ' . Horde::applicationUrl('deleventaction.php?' . $_SERVER['QUERY_STRING'], 1));
     exit;
@@ -41,5 +50,3 @@ if ($event->hasRecurType(KRONOLITH_RECUR_NONE)) {
     include KRONOLITH_TEMPLATES . '/delete/delete.inc';
 }
 require KRONOLITH_TEMPLATES . '/common-footer.inc';
-
-?>
