@@ -1,8 +1,8 @@
 <?php
 /*
- * $Horde:
+ * $Horde: kronolith/index.php,v 1.19.2.5 2005/01/03 11:25:58 jan Exp $
  *
- * Kronolith: Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Kronolith: Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL). If you did
  * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
@@ -15,21 +15,16 @@ $kronolith_configured = (@is_readable(KRONOLITH_BASE . '/config/conf.php') &&
 
 if ($kronolith_configured) {
     include_once KRONOLITH_BASE . '/lib/base.php';
-    
+
     $uri = $prefs->getValue('defaultview') . '.php';
     if ($uri == '.php') {
         $uri = 'month.php';
     }
-    if (!empty($HTTP_SERVER_VARS['QUERY_STRING'])) {
-        $uri .= '?' . $HTTP_SERVER_VARS['QUERY_STRING'];
+    if (!empty($_SERVER['QUERY_STRING'])) {
+        $uri .= '?' . $_SERVER['QUERY_STRING'];
     }
-    
+
     header('Location: ' . Horde::applicationUrl($uri, true));
-    exit;
-    
-/* Kronolith isn't configured */
 } else {
     include KRONOLITH_BASE . '/templates/index/notconfigured.inc';
 }
-
-?>
