@@ -3,11 +3,11 @@
  * The Kronolith_Driver_sql:: class implements the Kronolith_Driver
  * API for a SQL backend.
  *
- * $Horde: kronolith/lib/Driver/sql.php,v 1.31.2.13 2004/03/05 19:26:04 jan Exp $
+ * $Horde: kronolith/lib/Driver/sql.php,v 1.31.2.16 2004/04/03 04:12:59 chuck Exp $
  *
  * @author  Luc Saillard <luc.saillard@fr.alcove.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.31.2.13 $
+ * @version $Revision: 1.31.2.16 $
  * @since   Kronolith 0.3
  * @package kronolith
  */
@@ -89,7 +89,7 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             ' event_keywords, event_title, event_category,' .
             ' event_recurtype, event_recurenddate, event_recurinterval,' .
             ' event_recurdays, event_start, event_end, event_alarm,' .
-            ' event_modified, event_exceptions, event_creator_id FROM ' . $this->_params['table'] .
+            ' event_modified, event_exceptions FROM ' . $this->_params['table'] .
             ' WHERE calendar_id = ' . $this->_db->quote($this->_calendar) . ' AND ((';
 
         if ($hasAlarm) {
@@ -246,8 +246,8 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
 
         switch ($event->getRecurType()) {
         case KRONOLITH_RECUR_DAILY:
-            $diff = Kronolith::dateDiff($event->start, $afterDate);
-            $recur = ceil($diff->mday / $event->recurInterval) * $event->recurInterval;
+            $diff = Date_Calc::dateDiff($event->start->mday, $event->start->month, $event->start->year, $afterDate->mday, $afterDate->month, $afterDate->year);
+            $recur = ceil($diff / $event->recurInterval) * $event->recurInterval;
             $next = $event->start;
             list($next->mday, $next->month, $next->year) = explode('/', Date_Calc::daysToDate(Date_Calc::dateToDays($next->mday, $next->month, $next->year) + $recur, '%e/%m/%Y'));
             if (Kronolith::compareDates($next, $event->recurEnd) <= 0 &&
@@ -265,8 +265,9 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             $after_week_end = $after_week;
             $after_week_end->mday += 7;
             $after_week_end = Kronolith::correctDate($after_week_end);
-            $diff = Kronolith::dateDiff($start_week, $after_week);
-            $recur = $diff->mday + $diff->mday % ($event->recurInterval * 7);
+
+            $diff = Date_Calc::dateDiff($start_week->mday, $start_week->month, $start_week->year, $after_week->mday, $after_week->month, $after_week->year);
+            $recur = $diff + $diff % ($event->recurInterval * 7);
             $next = $start_week;
             list($next->mday, $next->month, $next->year) = explode('/', Date_Calc::daysToDate(Date_Calc::dateToDays($next->mday, $next->month, $next->year) + $recur, '%e/%m/%Y'));
             while (Kronolith::compareDates($next, $afterDate) < 0 && Kronolith::compareDates($next, $after_week_end) < 0) {
@@ -292,8 +293,12 @@ class Kronolith_Driver_sql extends Kronolith_Driver {
             break;
 
         case KRONOLITH_RECUR_DAY_OF_MONTH:
-            $diff = Kronolith::dateDiff($event->start, $afterDate);
-            $recur = $diff->month + $diff->month % $event->recurInterval;
+            $diff = Date_Calc::dateDiff($event->start->mday, $event->start->month, $event->start->year, $afterDate->mday, $afterDate->month, $afterDate->year);
+            $start = &Kronolith::dateObject($event->start);
+            $start->mday += $diff;
+            $diff = $start->month - $event->start->month + (($start->year - $event->start->year) * 12);
+
+            $recur = $diff + $diff % $event->recurInterval;
             $next = $event->start;
             $next->month += $recur;
             $next = Kronolith::correctDate($next);
