@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: kronolith/menu.php,v 1.13 2001/09/18 16:03:51 jan Exp $
+ * $Horde: kronolith/menu.php,v 1.14.2.4 2005/01/03 11:25:58 jan Exp $
  *
- * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999, 2000 Jon Parise <jon@horde.org>
+ * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL). If you did
  * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
@@ -32,13 +32,11 @@ if (!$timestamp) {
     $timestamp = mktime(0, 0, 0, $month, $day, $year);
 }
 $append = "?timestamp=$timestamp";
-  
-include $registry->getTemplatePath() . '/menu/menu.inc';
-require './status.php';
+
+include KRONOLITH_TEMPLATES . '/menu/menu.inc';
+require KRONOLITH_BASE . '/status.php';
 
 /* Include the JavaScript for the help system (if enabled). */
 if ($conf['user']['online_help'] && $browser->hasFeature('javascript')) {
     Help::javascript();
 }
-
-?>
